@@ -31,7 +31,6 @@
 #include "glxinfo.h" /* xxx_abbrev functions */
 
 #include "glx_banner.h"
-#include "ctkimage.h"
 #include "ctkglx.h"
 #include "ctkconfig.h"
 #include "ctkhelp.h"
@@ -67,16 +66,16 @@ static const char * __st_help =
   "st (Stereo buffer) - 'y' if the configuration has left and right color "
   "buffers that are rendered to in stereo.  '-' if this is not supported";
 static const char * __rs_help =
-  "rs (Red size) - Number of bits per color used for red. "
+  "rs (Red size) - Number of bits used for ammount of red per color. "
   "(Undefined for configurations that use color indexing.)";
 static const char * __gs_help =
-  "gs (Green size - Number of bits per color used for green. "
+  "gs (Green size - Number of bits used for ammount of green per color. "
   "(Undefined for configurations that use color indexing.)";
 static const char * __bs_help =
-  "bs (Blue size - Number of bits per color used for blue. "
+  "bs (Blue size - Number of bits used for ammount of blue per color. "
   "(Undefined for configurations that use color indexing.)";
 static const char * __as_help =
-  "as (Alpha size - Number of bits per color used for alpha. "
+  "as (Alpha size - Number of bits used for ammount of alpha per color. "
   "(Undefined for configurations that use color indexing.)";
 static const char * __aux_help =
   "aux (Auxillary buffers) - Number of available auxiliary color butters.";
@@ -85,17 +84,17 @@ static const char * __dpt_help =
 static const char * __stn_help =
   "stn (Stencil size) - Number of bits per element in the stencil buffer.";
 static const char * __acr_help =
-  "acr (Accumulator red size) - Number of bits per color used for red "
-  "in the accumulator buffer.";
+  "acr (Accumulator red size) - Number of bits used for ammount of red per "
+  "color in the accumulator buffer.";
 static const char * __acg_help =
-  "acg (Accumulator green size) - Number of bits per color used for green "
-  "in the accumulator buffer.";
+  "acg (Accumulator green size) - Number of bits used for ammount of green "
+  "per color in the accumulator buffer.";
 static const char * __acb_help =
-  "acb (Accumulator blue size) - Number of bits per color used for blue "
-  "in the accumulator buffer.";
+  "acb (Accumulator blue size) - Number of bits used for ammount of blue per "
+  "color in the accumulator buffer.";
 static const char * __aca_help =
-  "aca (Accumulator alpha size) - Number of bits per color used for alpha "
-  "in the accumulator buffer.";
+  "aca (Accumulator alpha size) - Number of bits used for ammount of alpha "
+  "per color in the accumulator buffer.";
 static const char * __ms_help =
   "ms (Multisample samples) - Number of samples per multisample.";
 static const char * __mb_help =
@@ -199,16 +198,22 @@ GtkWidget* ctk_glx_new(NvCtrlAttributeHandle *handle,
     GObject *object;
     CtkGLX *ctk_glx;
     GtkWidget *label;
-    GtkWidget *banner;
+    GtkWidget *image;
+    GtkWidget *frame;
     GtkWidget *hseparator;
     GtkWidget *hbox;
     GtkWidget *vbox, *vbox2;
+    GtkWidget *alignment;
     GtkWidget *table;
     GtkWidget *scrollWin;
     GtkWidget *event;    /* For setting the background color to white */
+    GdkColor   color;
 
     ReturnStatus ret;
 
+    guint8 *image_buffer = NULL;
+    const nv_image_t *img;    
+
     char * glx_info_str = NULL;               /* Test if GLX supported */
     GLXFBConfigAttr *fbconfig_attribs = NULL; /* FBConfig data */
     int i;                                    /* Iterator */
@@ -239,6 +244,10 @@ GtkWidget* ctk_glx_new(NvCtrlAttributeHandle *handle,
     };
 
 
+    /* Parse a white color (for background) */
+    gdk_color_parse ("white", &color);
+
+
     /* Create the ctk glx object */
     object = g_object_new(CTK_TYPE_GLX, NULL);
     ctk_glx = CTK_GLX(object);
@@ -252,10 +261,21 @@ GtkWidget* ctk_glx_new(NvCtrlAttributeHandle *handle,
     gtk_box_set_spacing(GTK_BOX(ctk_glx), 10);
 
     /* Image banner */
+    alignment = gtk_alignment_new(0, 0, 0, 0);
+    frame = gtk_frame_new(NULL);
+    img = &glx_banner_image;
+    image_buffer = decompress_image_data(img);
+    image = gtk_image_new_from_pixbuf
+        (gdk_pixbuf_new_from_data(image_buffer, GDK_COLORSPACE_RGB,
+                                  FALSE, 8, img->width, img->height,
+                                  img->width * img->bytes_per_pixel,
+                                  free_decompressed_image, NULL));
+    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
+    gtk_container_add(GTK_CONTAINER(frame), image);
+    gtk_container_add(GTK_CONTAINER(alignment), frame);
+    gtk_box_pack_start(GTK_BOX(ctk_glx), alignment, FALSE, FALSE, 0);
 
-    banner = ctk_banner_image_new(&glx_banner_image);
-    gtk_box_pack_start(GTK_BOX(ctk_glx), banner, FALSE, FALSE, 0);
-
+    
     /* Determine if GLX is supported */
     ret = NvCtrlGetStringAttribute(ctk_glx->handle,
                                    NV_CTRL_STRING_GLX_SERVER_VENDOR,
@@ -274,14 +294,12 @@ GtkWidget* ctk_glx_new(NvCtrlAttributeHandle *handle,
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollWin),
                                    GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
     gtk_box_pack_start(GTK_BOX(ctk_glx), scrollWin, TRUE, TRUE, 0);
-    gtk_widget_modify_fg(event, GTK_STATE_NORMAL, &(event->style->text[GTK_STATE_NORMAL]));
-    gtk_widget_modify_bg(event, GTK_STATE_NORMAL, &(event->style->base[GTK_STATE_NORMAL]));
+    gtk_widget_modify_bg(event, GTK_STATE_NORMAL, &color);
     gtk_container_add(GTK_CONTAINER(event), hbox);
     gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrollWin),
                                           event);
     gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 5);
     ctk_glx->glxinfo_vpane = vbox;
-    gtk_widget_set_size_request(scrollWin, -1, 200);
 
 
     /* GLX 1.3 supports frame buffer configurations */
@@ -310,7 +328,6 @@ GtkWidget* ctk_glx_new(NvCtrlAttributeHandle *handle,
                                     GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
     gtk_box_pack_start(GTK_BOX(ctk_glx), GTK_WIDGET(vbox), TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(vbox), scrollWin, TRUE, TRUE, 0);
-    gtk_widget_set_size_request(scrollWin, -1, 200);
 
     /*
      * NODE: Because clists have a hard time displaying tooltips in their
@@ -326,12 +343,9 @@ GtkWidget* ctk_glx_new(NvCtrlAttributeHandle *handle,
 
     table = gtk_table_new(i, NUM_FBCONFIG_ATTRIBS, FALSE);
     event = gtk_event_box_new();
-
-    gtk_widget_modify_fg(table, GTK_STATE_NORMAL, &(table->style->text[GTK_STATE_NORMAL]));
-    gtk_widget_modify_bg(table, GTK_STATE_NORMAL, &(table->style->base[GTK_STATE_NORMAL]));
+    gtk_widget_modify_bg (table, GTK_STATE_NORMAL, &color);
     gtk_container_add (GTK_CONTAINER(event), table);
-    gtk_widget_modify_fg(event, GTK_STATE_NORMAL, &(event->style->text[GTK_STATE_NORMAL]));
-    gtk_widget_modify_bg(event, GTK_STATE_NORMAL, &(event->style->base[GTK_STATE_NORMAL]));
+    gtk_widget_modify_bg(event, GTK_STATE_NORMAL, &color);
     gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrollWin),
                                           event);
     
@@ -456,6 +470,8 @@ GtkWidget* ctk_glx_new(NvCtrlAttributeHandle *handle,
                           "the X server or there was a problem retrieving\n"
                           "GLX information from the X server."
                           );
+    gdk_color_parse ("#FF0000", &color);
+    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &color);
     gtk_label_set_selectable(GTK_LABEL(label), TRUE);
 
     gtk_container_add(GTK_CONTAINER(ctk_glx), label);
