@@ -78,9 +78,6 @@ struct _CtkWindow
 
     GtkTreeIter             iter;
     GtkWidget              *widget;
-
-    GtkTextTagTable        *help_tag_table;
-    GtkTextBuffer          *help_text_buffer;
 };
 
 struct _CtkWindowClass
